# Salesforce ECA

## Introduction

Salesforce ECA integrates the Salesforce module with Drupal's
Event-Condition-Action (ECA) system. This module allows for automated
workflows to be triggered by Salesforce events, such as pushing data to
Salesforce, pulling data from Salesforce, and mapping Salesforce objects to
Drupal entities.

## Requirements

* Salesforce module
* Salesforce Mapping module
* Salesforce Push module
* Salesforce Pull module
* ECA module

## Installation

Install as you would normally install a Drupal module. Visit
https://www.drupal.org/node/1897420 for further information.

## Configuration

1. Navigate to ECA configuration at `/admin/config/workflow/eca`.
2. Create new ECA configurations that respond to Salesforce events.

## Features

* Expose Salesforce events to the ECA system
* Allow creation of conditions based on Salesforce data
* Provide actions that interact with Salesforce

## Maintainers

This module is part of the Salesforce Suite for Drupal.



## Available Events

The module exposes the following Salesforce events to ECA:

### Push Events
- **Push to Salesforce allowed** - Fires before pushing an entity to Salesforce
- **Push mapping object** - Fires immediately before processing a push
- **Push parameters** - Fires when preparing push parameters
- **Push success** - Fires after successfully pushing to Salesforce
- **Push failure** - Fires when pushing to Salesforce fails

### Pull Events
- **Pull query** - Fires before querying Salesforce
- **Pull enqueue** - Fires before enqueueing records for pull
- **Pull from Salesforce allowed** - Fires before pulling data
- **Pull entity value** - Fires before assigning field values during pull
- **Pull presave** - Fires before saving a pulled entity

## Available Actions

- **Execute SOQL query** - Execute a SOQL query against Salesforce and store
  results in tokens
- **Trigger entity push to Salesforce** - Force immediate push of an entity
  to Salesforce using its configured mapping
- **Trigger entity pull from Salesforce** - Pull latest data from Salesforce
  for an entity using its configured mapping

## Development Status

This module is ready for production use.
